camelot.camelot.view.field_attributes

Package camelot :: Package camelot :: Package view :: Module field_attributes |
[hide private]
[frames] | no frames]

# Module field_attributes

source code

Default field attributes for various sqlalchemy column types

Variables | [hide private]
| _sqlalchemy_to_python_type_ = `{sqlalchemy.types.Boolean: lambd`...``

Variables Details | [hide private]

  ### _sqlalchemy_to_python_type_ Value:
      {sqlalchemy.types.Boolean: lambda f: {'python_type': bool, 'editable':
       True, 'widget': QtGui.QCheckBox}, sqlalchemy.types.BOOLEAN: lambda f:
       {'python_type': bool, 'editable': True, 'widget': QtGui.QCheckBox}, s
      qlalchemy.types.Date: lambda f: {'python_type': datetime.date, 'format
      ': 'dd-mm-YYYY', 'editable': True, 'min': None, 'max': None, 'widget':
       DateEditor}, sqlalchemy.types.Float: lambda f: {'python_type': float,
       'precision': f.precision, 'editable': True, 'min': None, 'max': None,
       'widget': 'float'}, sqlalchemy.types.Integer: lambda f: {'python_type
      ...